```json
{
  "title": "KaTeX and MathJax Comparison Demo, currently processed as KaTeX",
  "author": "Murray Bourne",
  "site": "Murray Bourne",
  "published": ""
}
```

## KaTeX and MathJax Comparison Demo

Page by Murray Bourne, [IntMath.com](https://katex/). Last updated: 29 Apr 2020

### Repeating fractions

 $\displaystyle \frac{1}{\Bigl(\sqrt{\phi \sqrt{5}}-\phi\Bigr) e^{\frac25 \pi}} \equiv 1+\frac{e^{-2\pi}} {1+\frac{e^{-4\pi}} {1+\frac{e^{-6\pi}} {1+\frac{e^{-8\pi}} {1+\cdots} } } }$

### Summation notation

 $\displaystyle \left( \sum_{k=1}^n a_k b_k \right)^2 \leq \left( \sum_{k=1}^n a_k^2 \right) \left( \sum_{k=1}^n b_k^2 \right)$

### Inline math

And here is some in-line math: $k_{n+1} = n^2 + k_n^2 - k_{n-1}$, followed by some more text.

### Calculus

 $\displaystyle \int u \frac{dv}{dx}\,dx=uv-\int \frac{du}{dx}v\,dx$

### Lorenz Equations

 $\displaystyle \begin{aligned}
\dot{x} & = \sigma(y-x) \\
\dot{y} & = \rho x - y - xz \\
\dot{z} & = -\beta z + xy
\end{aligned}$

### Case definitions

 $\displaystyle f(n) = \begin{cases} \frac{n}{2}, & \text{if } n\text{ is even} \\ 3n+1, & \text{if } n\text{ is odd} \end{cases}$

### Matrices

 $\displaystyle \begin{pmatrix}
a_{11} & a_{12} & a_{13}\\
a_{21} & a_{22} & a_{23}\\
a_{31} & a_{32} & a_{33}
\end{pmatrix}$